%% plot the result of averaged percolation data
% first = 1 2 3 ----> uniform, exponential, log-normal distribution for the
% preexisting joints
% second = 1 2 3 ----> uniform, exponential, log-normal distribution for the
% cross joints
% type = 1 2 -----> elliptic aperture and log-normal distributed apertures
% ratio = 1 2 5 ----> segment lengths euqal 1, 0.5, 0.2
% In meandata: Column 1 to Column 8: Target fraction of open joints; 
% Simulated fraction of open joints; mean value of percolation probability; 
% mean size of the largest cluster; mean size of the mean cluster; 
% mean size of the second largest cluster; mean value of the fracture number;
% mean value of the segment number;
% similar definitions in stddata
clear
npd='3Ddata\';
first=1
second=1
type=[1,2]
ratio=[1,2,5]
num=1
for i=1:2
    for j=1:3
        dataname{num}=[npd,'\mean_percolation_first_',num2str(first),'_second_',num2str(second),'_type_',num2str(type(i)),'_ratio_',num2str(ratio(j)),'.txt']
        meandata{num} = dlmread( dataname{num}, '', 1)
        num=num+1;
    end
end
% add results of constant apertures;

dataname{num}=[npd,'\mean_percolation_noaperture_first_',num2str(first),'_second_',num2str(second),'_ratio_',num2str(ratio(1)),'.txt']
meandata{num} = dlmread(dataname{num}, '', 1)
num=num+1;
dataname{num}=[npd,'\mean_percolation_noaperture_first_',num2str(first),'_second_',num2str(second),'_ratio_',num2str(ratio(2)),'.txt']
meandata{num} = dlmread(dataname{num}, '', 1)
num=num+1;
dataname{num}=[npd,'\mean_percolation_noaperture_first_',num2str(first),'_second_',num2str(second),'_ratio_',num2str(ratio(3)),'.txt']
meandata{num} = dlmread(dataname{num}, '', 1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
nperco=3;
figure
marker=['o','s','h']
% plot cases with elliptic-shape apertures
for i=1:3
plotdata=meandata{i};
plot(plotdata(:,2),plotdata(:,nperco),['r',marker(i)],'markerfacecolor','r')
hold on
end
% plot cases with log-normal distributed apertures
 for i=4:6
plotdata=meandata{i};
plot(plotdata(:,2),plotdata(:,nperco),['g',marker(i-3)],'markerfacecolor','g')
hold on
 end
 % plot cases with constant apertures
for i=7:9
plotdata=meandata{i};
plot(plotdata(:,2),plotdata(:,nperco),['b',marker(i-6)],'markerfacecolor','b')
hold on
end

%% std value of each parameter;
num=1
for i=1:2
    for j=1:3
        dataname{num}=[npd,'\std_percolation_first_',num2str(first),'_second_',num2str(second),'_type_',num2str(type(i)),'_ratio_',num2str(ratio(j)),'.txt']
        stddata{num} = dlmread( dataname{num}, '', 1)
        num=num+1;
    end
end
% add results of constant apertures;
dataname{num}=[npd,'\std_percolation_noaperture_first_',num2str(first),'_second_',num2str(second),'_ratio_',num2str(ratio(1)),'.txt']
stddata{num} = dlmread(dataname{num}, '', 1)
num=num+1;
dataname{num}=[npd,'\std_percolation_noaperture_first_',num2str(first),'_second_',num2str(second),'_ratio_',num2str(ratio(2)),'.txt']
stddata{num} = dlmread(dataname{num}, '', 1)
num=num+1;
dataname{num}=[npd,'\std_percolation_noaperture_first_',num2str(first),'_second_',num2str(second),'_ratio_',num2str(ratio(3)),'.txt']
stddata{num} = dlmread(dataname{num}, '', 1)
nperco=3;
figure
marker=['o','s','h']
color=['r','g','b']
% plot cases with elliptic-shape apertures
for i=1:3
plotdata1=stddata{i};
plotdata2=meandata{i};
errorbar(plotdata2(:,2),plotdata2(:,nperco),plotdata1(:,nperco),[color(i),marker(1)],'markerfacecolor',[color(i)])
hold on
end
%%
% plot cases with log-normal distributed apertures
figure
for i=4:6
plotdata1=stddata{i};
plotdata2=meandata{i};
errorbar(plotdata2(:,2),plotdata2(:,nperco),plotdata1(:,nperco),[color(i-3),'o'],'markerfacecolor',[color(i-3)])
hold on
end
 %%
 % plot cases with constant apertures
figure
for i=7:9
plotdata1=stddata{i};
plotdata2=meandata{i};
errorbar(plotdata2(:,2),plotdata2(:,nperco),plotdata1(:,nperco),[color(i-6),marker(i-6)],'markerfacecolor',[color(i-6)])
hold on
end
ylabel('$$\mathrm{Percolation~ probability}$$', 'interpreter', 'latex','fontsize',16)
hold on
grid on
xlabel('$$\mathrm{Fraction~ of~ open~ joints}$$', 'interpreter', 'latex','fontsize',16)
%% %% plot the largest cluster size vs the fraction of open joints;
%% elliptical aperture 
nperco=2
nclustersize=4;
figure
for i=1:3
plotdata=meandata{i};
yyaxis left
plot(plotdata(:,2),plotdata(:,nclustersize),['b',marker(i)],'markerfacecolor','b')
ylim([0,1])
yyaxis left
ylabel('$$\mathrm{ L_{cluster}/L_{total}}$$', 'interpreter', 'latex','fontsize',16)
hold on
yyaxis right
plot(plotdata(:,2),plotdata(:,3),['r',marker(i)]','markerfacecolor','r')
ylabel('$$\mathrm{Percolation~ probability}$$', 'interpreter', 'latex','fontsize',16)
xlabel('$$\mathrm{Fraction~ of~ open~ joints}$$', 'interpreter', 'latex','fontsize',16)
hold on
end
%% log-normal distributed aperture
figure
for i=4:6
plotdata=meandata{i};
yyaxis left
plot(plotdata(:,nperco),plotdata(:,nclustersize),['b',marker(i-3)],'markerfacecolor','b')
ylim([0,1])
yyaxis left
ylabel('$$\mathrm{ L_{cluster}/L_{total}}$$', 'interpreter', 'latex','fontsize',16)
hold on
yyaxis right
plot(plotdata(:,nperco),plotdata(:,3),['r',marker(i-3)],'markerfacecolor','r')
ylabel('$$\mathrm{Percolation~ probability}$$', 'interpreter', 'latex','fontsize',16)
xlabel('$$\mathrm{Fraction~ of~ open~ joints}$$', 'interpreter', 'latex','fontsize',16)
hold on
end

%% constant aperture
figure
for i=7:9
plotdata=meandata{i};
yyaxis left
plot(plotdata(:,nperco),plotdata(:,nclustersize),['b',marker(i-6)],'markerfacecolor','b')
ylim([0,1])
yyaxis left
ylabel('$$\mathrm{ L_{cluster}/L_{total}}$$', 'interpreter', 'latex','fontsize',16)
hold on
yyaxis right
plot(plotdata(:,nperco),plotdata(:,3),['r',marker(i-6)],'markerfacecolor','r')
ylabel('$$\mathrm{Percolation~ probability}$$', 'interpreter', 'latex','fontsize',16)
xlabel('$$\mathrm{Fraction~ of~ open~ joints}$$', 'interpreter', 'latex','fontsize',16)
hold on
end 
%% example for small segment length Lse=0.05;
% Apertures follow a elliptical distribution, 
% and the spacing follows a uniform distribution for both preexisting and cross joints. 
npd='3Ddata\';
meandata=load([npd,'\percolation_first_1_second_1_type_1_id_10_ratio_20.txt'])
figure
yyaxis left
plot(meandata(:,2),meandata(:,4),'bo','markerfacecolor','b')
ylabel('$$\mathrm{Relative~size~of~cluster}$$', 'interpreter', 'latex','fontsize',16)
hold on
yyaxis right
plot(meandata(:,2),meandata(:,3),'ro','markerfacecolor','r')
ylabel('$$\mathrm{Percolation~ probability}$$', 'interpreter', 'latex','fontsize',16)
hold on
grid on